import requests

try:
    import xml.etree.cElementTree as ET
except ImportError:
    import xml.etree.ElementTree as ET


def get_current():
    ret = {}
    content = requests.get('https://invoice.etax.nat.gov.tw/invoice.xml')
    tree = ET.fromstring(content.text)
    items = list(tree.iter(tag='item'))
    title = items[0][0].text
    ret['title'] = title
    ptext = items[0][3].text
    ptext = ptext.replace('<p>', '')
    plist = ptext.split('</p>')

    for i in range(len(plist) - 1):
        tlist = plist[i].split('：')
        ret[tlist[0]] = tlist[1]

    return ret


import setuptools
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name = 'invoiceJB',
    version = '0.1.0',
    author = 'JamesBang',
    author_email = 'JBProgramNotes@gmail.com',
    description = 'Taiwan invoice number',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url = 'https://github.com/JBProgramNotes/invoiceJB',
    packages=setuptools.find_packages(),
    keywords = ['invoice'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
